pub(crate) enum CrateFeatureError {
TzSystem,
TzdbConcatenated,
TzdbZoneInfo,
}Expand description
An error used whenever a failure is caused by a missing crate feature.
This enum doesn’t necessarily contain every Jiff crate feature. It only contains the features whose absence can result in an error.
Variants