struct AdhocError {
message: Box<str>,
}Expand description
A generic error message.
This used to be used to represent most errors in Jiff. But then I switched
to more structured error types (internally). We still keep this around to
support the Error::from_args public API, which permits users of Jiff to
manifest their own Error values from an arbitrary message.
Fields
message: Box<str>Implementations
Sourceimpl AdhocError
impl AdhocError
fn from_args<'a>(message: Arguments<'a>) -> AdhocError