struct IOError {
err: Error,
}Expand description
A std::io::Error.
This type is itself always available, even when the std feature is not
enabled. When std is not enabled, a value of this type can never be
constructed.
Otherwise, this type is a simple wrapper around std::io::Error. Its
purpose is to encapsulate the conditional compilation based on the std
feature.
Fields
err: ErrorTrait Implementations
Sourceimpl Error for IOError
Available on crate feature std only.
impl Error for IOError
Available on crate feature
std only.1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()